===============================
Access CMIP5
===============================

.. image:: https://img.shields.io/travis/TaufiqHassan/acccmip5.svg
        :target: https://travis-ci.org/TaufiqHassan/acccmip5

.. image:: https://img.shields.io/pypi/v/acccmip5.svg
        :target: https://pypi.python.org/pypi/acccmip5


``acccmip5`` package can access CMIP5 database.

* GitHub repo: https://github.com/TaufiqHassan/acccmip5

Usage
-----
- Follow: https://github.com/TaufiqHassan/acccmip6

License
-------

This code is licensed under the `MIT License`_.

.. _`MIT License`: https://opensource.org/licenses/MIT
